# /*
#  * Copyright 2024 KylinSoft Co., Ltd.
#  *
#  * This program is free software: you can redistribute it and/or modify it under
#  * the terms of the GNU General Public License as published by the Free Software
#  * Foundation, either version 3 of the License, or (at your option) any later
#  * version.
#  *
#  * This program is distributed in the hope that it will be useful, but WITHOUT
#  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
#  * details.
#  *
#  * You should have received a copy of the GNU General Public License along with
#  * this program. If not, see <https://www.gnu.org/licenses/>.
#  */

import json
from .base_parser import BaseParser

class JSONParser(BaseParser):

    def parser(self, file_path) -> str:
        with open(file_path, 'r', encoding='utf-8') as file:
            data = json.load(file)
            return data


if __name__ == '__main__':
    image_parser = JSONParser()
    text = image_parser.parser('/home/kylin/wangyan/test-search/用户手册.json')
    print(text)
