# /*
#  * Copyright 2024 KylinSoft Co., Ltd.
#  *
#  * This program is free software: you can redistribute it and/or modify it under
#  * the terms of the GNU General Public License as published by the Free Software
#  * Foundation, either version 3 of the License, or (at your option) any later
#  * version.
#  *
#  * This program is distributed in the hope that it will be useful, but WITHOUT
#  * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
#  * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
#  * details.
#  *
#  * You should have received a copy of the GNU General Public License along with
#  * this program. If not, see <https://www.gnu.org/licenses/>.
#  */

from PIL import Image
import pytesseract
from .base_parser import BaseParser

"""
图片解析器,暂时不用
"""
class ImageParser(BaseParser):

    def parser(self, file_path) -> str:
        image = Image.open(file_path)
        text = pytesseract.image_to_string(image, lang='chi_sim')
        return text


if __name__ == '__main__':
    image_parser = ImageParser()
    text = image_parser.parser('/home/kylin/图片/2024-09-10_13-59-37.bmp')
    print(text)
