# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: document.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x64ocument.proto\x12\x08\x64ocument\"e\n\x0c\x43hunkRequest\x12\x12\n\nfile_paths\x18\x01 \x03(\t\x12\x15\n\rchunker_types\x18\x02 \x03(\t\x12\x13\n\x0b\x63hunk_sizes\x18\x03 \x03(\x05\x12\x15\n\rcallback_data\x18\x04 \x03(\t\"1\n\x0cResponseData\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x0e\n\x06\x63hunks\x18\x02 \x03(\t\"@\n\x0f\x43hunkedResponse\x12-\n\rresponse_data\x18\x01 \x03(\x0b\x32\x16.document.ResponseData2\xee\x01\n\x0f\x44ocumentService\x12\x46\n\x11SyncChunkDocument\x12\x16.document.ChunkRequest\x1a\x19.document.ChunkedResponse\x12G\n\x12\x41syncChunkDocument\x12\x16.document.ChunkRequest\x1a\x19.document.ChunkedResponse\x12J\n\x13StreamChunkDocument\x12\x16.document.ChunkRequest\x1a\x19.document.ChunkedResponse0\x01\x62\x06proto3')



_CHUNKREQUEST = DESCRIPTOR.message_types_by_name['ChunkRequest']
_RESPONSEDATA = DESCRIPTOR.message_types_by_name['ResponseData']
_CHUNKEDRESPONSE = DESCRIPTOR.message_types_by_name['ChunkedResponse']
ChunkRequest = _reflection.GeneratedProtocolMessageType('ChunkRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKREQUEST,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:document.ChunkRequest)
  })
_sym_db.RegisterMessage(ChunkRequest)

ResponseData = _reflection.GeneratedProtocolMessageType('ResponseData', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEDATA,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:document.ResponseData)
  })
_sym_db.RegisterMessage(ResponseData)

ChunkedResponse = _reflection.GeneratedProtocolMessageType('ChunkedResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHUNKEDRESPONSE,
  '__module__' : 'document_pb2'
  # @@protoc_insertion_point(class_scope:document.ChunkedResponse)
  })
_sym_db.RegisterMessage(ChunkedResponse)

_DOCUMENTSERVICE = DESCRIPTOR.services_by_name['DocumentService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHUNKREQUEST._serialized_start=28
  _CHUNKREQUEST._serialized_end=129
  _RESPONSEDATA._serialized_start=131
  _RESPONSEDATA._serialized_end=180
  _CHUNKEDRESPONSE._serialized_start=182
  _CHUNKEDRESPONSE._serialized_end=246
  _DOCUMENTSERVICE._serialized_start=249
  _DOCUMENTSERVICE._serialized_end=487
# @@protoc_insertion_point(module_scope)
